@@ -7,24 +7,24 @@ s3_strip_class_impl <- function(x) {
     return(x)
   }
 
-  f.c <- strsplit(x, ".", fixed = TRUE)[[1]]
-  nfc <- length(f.c)
+  f_c <- strsplit(x, ".", fixed = TRUE)[[1]]
+  nfc <- length(f_c)
 
   if (nfc == 2) {
-    return(f.c[[1L]])
+    return(f_c[[1L]])
   }
 
   ok <- logical(nfc)
   for (j in 2:nfc) {
     ok[[j]] <- utils::isS3method(
-      f = paste(f.c[1:(j - 1)], collapse = "."),
-      class = paste(f.c[j:nfc], collapse = ".")
+      f = paste(f_c[1:(j - 1)], collapse = "."),
+      class = paste(f_c[j:nfc], collapse = ".")
     )
   }
 
   .f <- character(nfc)
   for (j in 2:nfc) {
-    .f[[j]] <- paste(f.c[1:(j - 1)], collapse = ".")
+    .f[[j]] <- paste(f_c[1:(j - 1)], collapse = ".")
   }
 
   .f[which(ok)]
